cwlVersion: v1.2
class: Workflow
doc: >-
  The workflow starts with selecting RPE as the search term. For the given gene
  ID (SYMBOL), StringDB PPI was extracted using their API[1]. For the Given
  StringDB PPI, the list of nodes (Gene Set) is generated. For the Given
  StringDB PPI, the list of nodes (GeneSet) is generated. Reversers and
  mimickers from over 1 million signatures were identified using SigCom
  LINCS[2]. The gene set was submitted to Enrichr[4]. The gene set was then
  searched in the Metabolomics Workbench[5] to identify relevant reactions. The
  gene set was then searched in the Metabolomics Workbench [Metabolomics
  Workbench, [7] to identify associated metabolites. The gene set was then
  searched in the Metabolomics Workbench[5] to identify relevant studies related
  to the genes. 

  1. Szklarczyk, D. et al. The STRING database in 2023: protein–protein
  association networks and functional enrichment analyses for any sequenced
  genome of interest. Nucleic Acids Research vol. 51 D638–D646 (2022).
  doi:10.1093/nar/gkac1000

  2. Evangelista, J. E. et al. SigCom LINCS: data and metadata search engine for
  a million gene expression signatures. Nucleic Acids Research vol. 50 W697–W709
  (2022). doi:10.1093/nar/gkac328

  4. Xie, Z. et al. Gene Set Knowledge Discovery with Enrichr. Current Protocols
  vol. 1 (2021). doi:10.1002/cpz1.90

  5. The Metabolomics Workbench, https://www.metabolomicsworkbench.org/

  7. https://www.metabolomicsworkbench.org/
requirements: {}
inputs:
  step-1-data:
    label: Gene Input
    doc: Start with a Gene
    type: File
outputs:
  step-1-output:
    label: Gene
    doc: Gene Term
    type: File
    outputSource: step-1/output
  step-2-output:
    label: StringDB PPI network
    doc: StringDB PPI network
    type: File
    outputSource: step-2/output
  step-3-output:
    label: Graph Plot
    doc: A graph plot rendered using the [cytoscape.js
      library](https://js.cytoscape.org/)
    type: File
    outputSource: step-3/output
  step-4-output:
    label: Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-4/output
  step-5-output:
    label: SigCom LINCS Gene Set Search Results
    doc: LINCS L1000 Gene Set Query Results
    type: File
    outputSource: step-5/output
  step-6-output:
    label: Enrichr Enrichment Analysis
    doc: A gene set submitted to [Enrichr](https://maayanlab.cloud/Enrichr/)
    type: File
    outputSource: step-6/output
  step-7-output:
    label: MetGENE Reaction Table
    doc: MetGENE Reaction Table
    type: File
    outputSource: step-7/output
  step-8-output:
    label: MetGENE metabolite table
    doc: MetGENE metabolite table
    type: File
    outputSource: step-8/output
  step-9-output:
    label: MetGENE Studies Table
    doc: Studies table corresponding to gene
    type: File
    outputSource: step-9/output
steps:
  step-1:
    run: Input[Gene].cwl
    label: Gene Input
    doc: Start with a Gene
    in:
      data:
        source: step-1-data
      outputFilename:
        default: step-1-output.json
    out:
      - output
  step-2:
    run: FetchStringDBPPI.cwl
    label: Fetch StringDB PPI
    doc: Given a gene or gene set (SYMBOL), extract PPI using StringDB APIs
    in:
      inputs.gene:
        label: Gene
        source: step-1/output
      outputFilename:
        default: step-2-output.json
    out:
      - output
  step-3:
    run: StringDBPPI_to_GraphPlot.cwl
    label: Reformat StringDB PPI for plotting
    doc: Given StringDB PPI, reformat for plotting
    in:
      inputs.data:
        label: StringDB PPI network
        source: step-2/output
      outputFilename:
        default: step-3-output.json
    out:
      - output
  step-4:
    run: StringDBPPI_to_GeneSet.cwl
    label: Given StringDB PPI, generate the list of nodes (GeneSet)
    doc: Given StringDB PPI, generate the list of nodes (GeneSet)
    in:
      inputs.data:
        label: StringDB PPI network
        source: step-2/output
      outputFilename:
        default: step-4-output.json
    out:
      - output
  step-5:
    run: SigComLINCSGeneSetSearch.cwl
    label: SigCom LINCS Gene Set Search
    doc: Query LINCS L1000 Signatures
    in:
      inputs.genes:
        label: Gene Set
        source: step-4/output
      outputFilename:
        default: step-5-output.json
    out:
      - output
  step-6:
    run: EnrichrGenesetSearch.cwl
    label: Enrichr Enrichment Analysis
    doc: Perform Enrichment Analysis
    in:
      inputs.geneset:
        label: Gene Set
        source: step-4/output
      outputFilename:
        default: step-6-output.json
    out:
      - output
  step-7:
    run: MetGeneRxnsSet.cwl
    label: MetGENE Reactions with Gene Set
    doc: Compute the MetGENE Reactions for a Gene Set
    in:
      inputs.geneset:
        label: Gene Set
        source: step-4/output
      outputFilename:
        default: step-7-output.json
    out:
      - output
  step-8:
    run: MetgeneMetabolitesGeneSet.cwl
    label: MetGENE Metabolites with Gene Set
    doc: Compute the MetGENE metabolites for a Gene Set
    in:
      inputs.geneset:
        label: Gene Set
        source: step-4/output
      outputFilename:
        default: step-8-output.json
    out:
      - output
  step-9:
    run: MetGeneStudiesGeneSet.cwl
    label: MetGENE Studies with Gene Set
    doc: Compute the MetGENE studies function for a gene set
    in:
      inputs.geneset:
        label: Gene Set
        source: step-4/output
      outputFilename:
        default: step-9-output.json
    out:
      - output
